@@ -69,7 +69,7 @@ from calculate.install.distr import (Distributive, IsoDistributive,
 import shutil
 from functools import partial
 import os
-from os import path
+from os import path, listdir
 from .datavars import BuilderError
 from .emerge_fetch import EmergeFetcher, EmergeFetcherError
 from calculate.lib.utils.grub import GrubCommand
@@ -1358,7 +1358,7 @@ class Builder(Update):
             if path.exists(dbPkg) and path.exists(pkgDir):
                 # get pkg list from distro
                 pkgList = reduce(lambda x, y: x + y,
-                    [[path.join(x, "%s.tbz2" % z) for z 
+                    [[path.join(dbPkg, x, z) for z 
                         in os.listdir(path.join(dbPkg, x))] for x 
                             in os.listdir(dbPkg)],  
                     [])
@@ -1371,7 +1371,21 @@ class Builder(Update):
                         if path.isdir(z))],
                     [])
                 # remove files which in binary and not in db/pkg
-                removeList = list(set(binList) - set(pkgList))
+                removeList = []
+                for binPkg in binList:
+                    # Удаляем расширения файлов, чтобы получить базовые имена
+                    pkgName = path.splitext(binPkg)[0]
+                    tbz2 = f"{pkgName}.tbz2"
+                    gpkg = f"{pkgName}.gpkg.tar"
+                    # Сравниваем имена пакетов
+                    if pkgName in pkgList:
+                        # Приоритет у gpkg, удаляем tbz2 при наличии обоих
+                        if tbz2 in binList and gpkg in binList:
+                            removeList.append(tbz2)
+                    else:
+                        removeList.append(binPkg)
+
+
                 if removeList:
                     removelist_str = ",".join(
                         path.basename(x) for x in removeList)
